==> cybop-0.18.0.tar.gz: cybop-0.18.0/src/executor/maintainer/starter/serial_port/set_status_serial_port_starter.c <==
/*
 * Copyright (C) 1999-2016. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.18.0 2016-12-21
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef SET_STATUS_SERIAL_PORT_STARTER_SOURCE
#define SET_STATUS_SERIAL_PORT_STARTER_SOURCE

#ifdef __APPLE__
    //?? Check for Apple - maybe some problems in the library
#elif WIN32
    //currently not supported
#elif GNU_LINUX_OPERATING_SYSTEM
#include <stdio.h>
#include <sys/ioctl.h>
#include <termios.h>

#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
#include "../../../../constant/model/cyboi/log/message_log_cyboi_model.c"
#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
#include "../../../../constant/name/cyboi/state/internal_memory_state_cyboi_name.c"
#include "../../../../constant/type/cyboi/state_cyboi_type.c"
#include "../../../../logger/logger.c"

/**
 * Starts up the serial port status setter.
 *
 * @param p0 the file descriptor data
 * @param p1 the status
 */
void startup_serial_port_status_set(void* p0, void* p1) {
    
    if (p1 != *NULL_POINTER_STATE_CYBOI_MODEL) {
        
        int* s = (int*) p1;
        
        if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
            
            int* d = (int*) p0;
            
            log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Startup serial port status set.");
            
            // Turn on DTR.
            *s |= TIOCM_DTR;
            // Turn on RTS.
            *s |= TIOCM_RTS;
            
            // Set serial port status.
            int e = ioctl(*d, TIOCMSET, s);
            
            if (e < *NUMBER_0_INTEGER_STATE_CYBOI_MODEL) {
                
                // Close serial port on error.
                close(*d);
                
                log_message_terminated((void*) WARNING_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status set. Could not set serial port status.");
            }
            
        } else {
            
            log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status set. The serial port file descriptor data is null.");
        }
        
    } else {
        
        log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status set. The serial port status is null.");
    }
}

/* GNU_LINUX_OPERATING_SYSTEM */
#else
#include <stdio.h>
#include <sys/ioctl.h>
#include <termios.h>

#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
#include "../../../../constant/model/cyboi/log/message_log_cyboi_model.c"
#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
#include "../../../../constant/name/cyboi/state/internal_memory_state_cyboi_name.c"
#include "../../../../constant/type/cyboi/state_cyboi_type.c"
#include "../../../../logger/logger.c"

/**
 * Starts up the serial port status setter.
 *
 * @param p0 the file descriptor data
 * @param p1 the status
 */
void startup_serial_port_status_set(void* p0, void* p1) {
    
    if (p1 != *NULL_POINTER_STATE_CYBOI_MODEL) {
        
        int* s = (int*) p1;
        
        if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
            
            int* d = (int*) p0;
            
            log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Startup serial port status set.");
            
            // Turn on DTR.
            *s |= TIOCM_DTR;
            // Turn on RTS.
            *s |= TIOCM_RTS;
            
            // Set serial port status.
            int e = ioctl(*d, TIOCMSET, s);
            
            if (e < *NUMBER_0_INTEGER_STATE_CYBOI_MODEL) {
                
                // Close serial port on error.
                close(*d);
                
                log_message_terminated((void*) WARNING_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status set. Could not set serial port status.");
            }
            
        } else {
            
            log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status set. The serial port file descriptor data is null.");
        }
        
    } else {
        
        log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status set. The serial port status is null.");
    }
}

/* Other UNIX based systems */
#endif


/* SET_STATUS_SERIAL_PORT_STARTER_SOURCE */
#endif

==> cybop-0.19.0.tar.gz: cybop-0.19.0/src/executor/maintainer/starter/serial_port/set_status_serial_port_starter.c <==
/*
 * Copyright (C) 1999-2017. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.19.0 2017-04-10
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef SET_STATUS_SERIAL_PORT_STARTER_SOURCE
#define SET_STATUS_SERIAL_PORT_STARTER_SOURCE

#if defined(__linux__) || defined(__unix__)
    #include <stdio.h>
    #include <sys/ioctl.h>
    #include <termios.h>
#elif defined(__APPLE__) && defined(__MACH__)
    //?? Check for Apple - maybe some problems in the library
    #include <stdio.h>
    #include <sys/ioctl.h>
    #include <termios.h>
// Use __CYGWIN__ too, if _WIN32 is not known to mingw.
#elif defined(_WIN32) || defined(__CYGWIN__)
    // Empty.
#else
    #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
#endif

#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
 
#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
#include "../../../../constant/name/cyboi/state/internal_memory_state_cyboi_name.c"
#include "../../../../constant/type/cyboi/state_cyboi_type.c"
#include "../../../../logger/logger.c"

/**
 * Starts up the serial port status setter.
 *
 * @param p0 the file descriptor data
 * @param p1 the status
 */
void startup_serial_port_status_set(void* p0, void* p1) {

    if (p1 != *NULL_POINTER_STATE_CYBOI_MODEL) {

        int* s = (int*) p1;

        if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {

            int* d = (int*) p0;

            log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Startup serial port status set.");

#ifndef _WIN32
            // Turn on DTR.
            *s |= TIOCM_DTR;
            // Turn on RTS.
            *s |= TIOCM_RTS;

            // Set serial port status.
            int e = ioctl(*d, TIOCMSET, s);

            if (e < *NUMBER_0_INTEGER_STATE_CYBOI_MODEL) {

                // Close serial port on error.
                close(*d);

                log_message_terminated((void*) WARNING_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status set. Could not set serial port status.");
            }
#endif

        } else {

            log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status set. The serial port file descriptor data is null.");
        }

    } else {

        log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not startup serial port status set. The serial port status is null.");
    }
}

/* SET_STATUS_SERIAL_PORT_STARTER_SOURCE */
#endif
